;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "kaolin-themes" "20251007.1241"
  "A set of eye pleasing themes."
  '((emacs      "25.1")
    (autothemer "0.2.2")
    (cl-lib     "0.6"))
  :url "https://github.com/ogdenwebb/emacs-kaolin-themes"
  :commit "a0570401fa08fb6f3843e574d28823a8e079e943"
  :revdesc "a0570401fa08"
  :keywords '("dark" "light" "teal" "blue" "violet" "purple" "brown" "theme" "faces")
  :authors '(("Ogden Webb" . "ogdenwebb@gmail.com"))
  :maintainers '(("Ogden Webb" . "ogdenwebb@gmail.com")))
